Learn R Programming

hsstan (version 0.8.2)

diabetes: Diabetes data with interaction terms

Description

The dataset consists of observations on 442 individuals for which a quantitative measure of diabetes progression is recorded in variable Y. Predictors include 10 baseline measurements, 45 interactions and 9 quadratic terms, for a total of 64 variables for each individual. Each variable has been standardized by subtracting the mean and then dividing it by its standard deviation.

Arguments

Format

A data frame with 442 rows and 65 columns (centred and scaled).

Examples

Run this code
data(diabetes, package="hsstan")

Run the code above in your browser using DataLab