Learn R Programming

hsstan (version 0.8.2)

log_lik.hsstan: Pointwise log-likelihood

Description

Compute the pointwise log-likelihood.

Usage

# S3 method for hsstan
log_lik(object, newdata = NULL, ...)

Value

A matrix of size S by N, where S is number of draws from the posterior distribution, and N is the number of data points.

Arguments

object

An object of class hsstan.

newdata

Optional data frame to use to evaluate the log-likelihood. If NULL (default), the model matrix is used.

...

Currently ignored.

Examples

Run this code
utils::example("hsstan", echo=FALSE)
# continued from ?hsstan
log_lik(hs.biom)

Run the code above in your browser using DataLab