A matrix of size S by N, where S is the number of draws from the
posterior distribution of the (transformed) linear predictor, and N is
the number of data points.
Arguments
object
An object of class hsstan.
transform
Whether the linear predictor should be transformed using
the inverse-link function (FALSE by default).
newdata
Optional data frame containing the variables to use to
predict. If NULL (default), the model matrix is used. If
specified, its continuous variables should be standardized, since
the model coefficients are learnt on standardized data.