powered by
Compute the pointwise log-likelihood.
# S3 method for hsstan log_lik(object, newdata = NULL, ...)
A matrix of size S by N, where S is number of draws from the posterior distribution, and N is the number of data points.
S
N
An object of class hsstan.
hsstan
Optional data frame to use to evaluate the log-likelihood. If NULL (default), the model matrix is used.
NULL
Currently ignored.
utils::example("hsstan", echo=FALSE) # continued from ?hsstan log_lik(hs.biom)
Run the code above in your browser using DataLab